@@ -19,13 +19,14 @@
     GyMMM => "MMM y G",
     GyMMMEd => "E\N{U+060c} d MMM y G",
     GyMMMd => "d MMM y G",
+    GyMd => "dd-MM-y GGGGG",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
     Hmsv => "HH:mm:ss v",
     Hmv => "HH:mm v",
     M => "L",
-    MEd => "E\N{U+060c} d/M",
+    MEd => "E\N{U+060c} d\N{U+200f}/M",
     MMM => "LLL",
     MMMEd => "E\N{U+060c} d MMM",
     MMMMEd => "E\N{U+060c} d MMMM",
@@ -38,9 +39,9 @@
     MMMMd => "d MMMM",
     MMMd => "d MMM",
     MMdd => "dd\N{U+200f}/MM",
-    Md => "d/\N{U+200f}M",
+    Md => "d\N{U+200f}/M",
     d => "d",
-    h => "h a",
+    h => "h\N{U+202f}a",
     hm => "h:mm a",
     hms => "h:mm:ss a",
     hmsv => "h:mm:ss a v",
@@ -48,7 +49,7 @@
     ms => "mm:ss",
     y => "y",
     yM => "M\N{U+200f}/y",
-    yMEd => "E\N{U+060c} d/\N{U+200f}M/\N{U+200f}y",
+    yMEd => "E\N{U+060c} d\N{U+200f}/M\N{U+200f}/y",
     yMM => "MM\N{U+200f}/y",
     yMMM => "MMM y",
     yMMMEd => "E\N{U+060c} d MMM y",
@@ -69,10 +70,10 @@
   date_format_long => "d MMMM y",
   date_format_medium => "dd\N{U+200f}/MM\N{U+200f}/y",
   date_format_short => "d\N{U+200f}/M\N{U+200f}/y",
-  datetime_format_full => "{1} {0}",
-  datetime_format_long => "{1} {0}",
-  datetime_format_medium => "{1} {0}",
-  datetime_format_short => "{1} {0}",
+  datetime_format_full => "{1}\N{U+060c} {0}",
+  datetime_format_long => "{1}\N{U+060c} {0}",
+  datetime_format_medium => "{1}\N{U+060c} {0}",
+  datetime_format_short => "{1}\N{U+060c} {0}",
   day_format_abbreviated => [
     "\N{U+0627}\N{U+0644}\N{U+0627}\N{U+062b}\N{U+0646}\N{U+064a}\N{U+0646}",
     "\N{U+0627}\N{U+0644}\N{U+062b}\N{U+0644}\N{U+0627}\N{U+062b}\N{U+0627}\N{U+0621}",
@@ -140,11 +141,11 @@
     "\N{U+0645}\N{U+064a}\N{U+0644}\N{U+0627}\N{U+062f}\N{U+064a}",
   ],
   first_day_of_week => 6,
-  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
+  glibc_date_1_format => "%d %b, %Y %Z %I:%M:%S %p",
   glibc_date_format => "%d %b, %Y",
-  glibc_datetime_format => "%d %b, %Y %Z %I:%M:%S %p",
+  glibc_datetime_format => "%d %b, %Y %I:%M:%S %p",
   glibc_time_12_format => "%Z %I:%M:%S %p",
-  glibc_time_format => "%Z %I:%M:%S ",
+  glibc_time_format => "%Z %I:%M:%S %p",
   language => "Arabic",
   month_format_abbreviated => [
     "\N{U+062c}\N{U+0627}\N{U+0646}\N{U+0641}\N{U+064a}",
@@ -279,5 +280,5 @@
   time_format_medium => "h:mm:ss a",
   time_format_short => "h:mm a",
   variant => undef,
-  version => 35,
+  version => 47,
 }
