@@ -8,17 +8,20 @@
     Bhm => "h:mm B",
     Bhms => "h:mm:ss B",
     E => "ccc",
-    EBhm => "E, h:mm B",
-    EBhms => "E, h:mm:ss B",
+    EBhm => "E h:mm B",
+    EBhms => "E h:mm:ss B",
     EHm => "E H.mm",
     EHms => "E H.mm.ss",
     Ed => "E d",
-    Ehm => "E h.mm a",
-    Ehms => "E h.mm.ss a",
+    Ehm => "E h.mm\N{U+202f}a",
+    "Ehm-alt-ascii" => "E h.mm a",
+    Ehms => "E h.mm.ss\N{U+202f}a",
+    "Ehms-alt-ascii" => "E h.mm.ss a",
     Gy => "y G",
     GyMMM => "MMM y G",
     GyMMMEd => "E, d MMM y G",
     GyMMMd => "d MMM y G",
+    GyMd => "d/M/y G",
     H => "HH",
     Hm => "H.mm",
     Hms => "H.mm.ss",
@@ -35,11 +38,16 @@
     MMdd => "dd/MM",
     Md => "dd/MM",
     d => "d",
-    h => "h a",
-    hm => "h.mm a",
-    hms => "h.mm.ss a",
-    hmsv => "h.mm.ss a v",
-    hmv => "h.mm a v",
+    h => "h\N{U+202f}a",
+    "h-alt-ascii" => "h a",
+    hm => "h.mm\N{U+202f}a",
+    "hm-alt-ascii" => "h.mm a",
+    hms => "h.mm.ss\N{U+202f}a",
+    "hms-alt-ascii" => "h.mm.ss a",
+    hmsv => "h.mm.ss\N{U+202f}a v",
+    "hmsv-alt-ascii" => "h.mm.ss a v",
+    hmv => "h.mm\N{U+202f}a v",
+    "hmv-alt-ascii" => "h.mm a v",
     ms => "mm.ss",
     y => "y",
     yM => "MM/y",
@@ -59,8 +67,8 @@
   date_format_long => "d MMMM y",
   date_format_medium => "d MMM y",
   date_format_short => "dd/MM/y",
-  datetime_format_full => "{1} 'at' {0}",
-  datetime_format_long => "{1} 'at' {0}",
+  datetime_format_full => "{1}, {0}",
+  datetime_format_long => "{1}, {0}",
   datetime_format_medium => "{1}, {0}",
   datetime_format_short => "{1}, {0}",
   day_format_abbreviated => [
@@ -145,7 +153,7 @@
     "Jun",
     "Jul",
     "Aug",
-    "Sep",
+    "Sept",
     "Oct",
     "Nov",
     "Dec",
@@ -187,7 +195,7 @@
     "Jun",
     "Jul",
     "Aug",
-    "Sep",
+    "Sept",
     "Oct",
     "Nov",
     "Dec",
@@ -269,5 +277,5 @@
   time_format_medium => "H.mm.ss",
   time_format_short => "H.mm",
   variant => undef,
-  version => 35,
+  version => 47,
 }
