@@ -14,7 +14,9 @@
     EHms => "E HH:mm:ss",
     Ed => "E d",
     Ehm => "E h:mm\N{U+202f}a",
+    "Ehm-alt-ascii" => "E h:mm a",
     Ehms => "E h:mm:ss\N{U+202f}a",
+    "Ehms-alt-ascii" => "E h:mm:ss a",
     Gy => "y G",
     GyMMM => "MMM y G",
     GyMMMEd => "E, d MMM y G",
@@ -37,10 +39,15 @@
     Md => "dd/MM",
     d => "d",
     h => "h\N{U+202f}a",
+    "h-alt-ascii" => "h a",
     hm => "h:mm\N{U+202f}a",
+    "hm-alt-ascii" => "h:mm a",
     hms => "h:mm:ss\N{U+202f}a",
+    "hms-alt-ascii" => "h:mm:ss a",
     hmsv => "h:mm:ss\N{U+202f}a v",
+    "hmsv-alt-ascii" => "h:mm:ss a v",
     hmv => "h:mm\N{U+202f}a v",
+    "hmv-alt-ascii" => "h:mm a v",
     ms => "mm:ss",
     y => "y",
     yM => "MM/y",
@@ -270,5 +277,5 @@
   time_format_medium => "h:mm:ss\N{U+202f}a",
   time_format_short => "h:mm\N{U+202f}a",
   variant => undef,
-  version => 42,
+  version => 47,
 }
