@@ -21,9 +21,9 @@
     GyMMMd => "G y MMM d",
     GyMd => "GGGGG y-MM-dd",
     H => "HH",
-    Hm => "HH:mm",
-    Hms => "HH:mm:ss",
-    Hmsv => "HH:mm:ss v",
+    Hm => "'Kl'. H.mm",
+    Hms => "'Klock' H.mm:ss",
+    Hmsv => "'Klock' H.mm:ss\N{U+202f}v",
     Hmv => "HH:mm v",
     M => "L",
     MEd => "MM-dd, E",
@@ -34,10 +34,10 @@
     MMMd => "MMM d",
     Md => "MM-dd",
     d => "d",
-    h => "h a",
-    hm => "h:mm a",
-    hms => "h:mm:ss a",
-    hmsv => "h:mm:ss a v",
+    h => "h\N{U+202f}a",
+    hm => "'Kl'. h.mm\N{U+202f}a",
+    hms => "'Klock' h.mm:ss\N{U+202f}a",
+    hmsv => "'Klock' h.mm:ss\N{U+202f}a\N{U+202f}v",
     hmv => "h:mm a v",
     ms => "mm:ss",
     y => "y",
@@ -46,8 +46,8 @@
     yMMM => "y MMM",
     yMMMEd => "y MMM d, E",
     yMMMM => "y MMMM",
-    yMMMd => "y MMM d",
-    yMd => "y-MM-dd",
+    yMMMd => "d. MMM y",
+    yMd => "d.M.y",
     yQQQ => "y QQQ",
     yQQQQ => "y QQQQ",
     "yw-count-other" => "'week' w 'of' Y",
@@ -62,13 +62,13 @@
   datetime_format_medium => "{1} {0}",
   datetime_format_short => "{1} {0}",
   day_format_abbreviated => [
-    "Mon",
-    "Tue",
-    "Wed",
-    "Thu",
-    "Fri",
-    "Sat",
-    "Sun",
+    "Maandag",
+    "Dingsdag",
+    "Middeweken",
+    "Dunnersdag",
+    "Freedag",
+    "S\N{U+00fc}nnavend",
+    "S\N{U+00fc}nndag",
   ],
   day_format_narrow => [
     "M",
@@ -80,22 +80,22 @@
     "S",
   ],
   day_format_wide => [
-    "Mon",
-    "Tue",
-    "Wed",
-    "Thu",
-    "Fri",
-    "Sat",
-    "Sun",
+    "Maandag",
+    "Dingsdag",
+    "Middeweken",
+    "Dunnersdag",
+    "Freedag",
+    "S\N{U+00fc}nnavend",
+    "S\N{U+00fc}nndag",
   ],
   day_stand_alone_abbreviated => [
-    "Mon",
-    "Tue",
-    "Wed",
-    "Thu",
-    "Fri",
-    "Sat",
-    "Sun",
+    "Maandag",
+    "Dingsdag",
+    "Middeweken",
+    "Dunnersdag",
+    "Freedag",
+    "S\N{U+00fc}nnavend",
+    "S\N{U+00fc}nndag",
   ],
   day_stand_alone_narrow => [
     "M",
@@ -107,13 +107,13 @@
     "S",
   ],
   day_stand_alone_wide => [
-    "Mon",
-    "Tue",
-    "Wed",
-    "Thu",
-    "Fri",
-    "Sat",
-    "Sun",
+    "Maandag",
+    "Dingsdag",
+    "Middeweken",
+    "Dunnersdag",
+    "Freedag",
+    "S\N{U+00fc}nnavend",
+    "S\N{U+00fc}nndag",
   ],
   era_abbreviated => [
     "BCE",
@@ -135,18 +135,18 @@
   glibc_time_format => "%T",
   language => "Low German",
   month_format_abbreviated => [
-    "M01",
-    "M02",
-    "M03",
-    "M04",
-    "M05",
-    "M06",
-    "M07",
-    "M08",
-    "M09",
-    "M10",
-    "M11",
-    "M12",
+    "Januaar",
+    "Februaar",
+    "M\N{U+00e4}rz",
+    "April",
+    "Mai",
+    "Juni",
+    "Juli",
+    "August",
+    "September",
+    "Oktover",
+    "November",
+    "Dezember",
   ],
   month_format_narrow => [
     1,
@@ -163,32 +163,32 @@
     12,
   ],
   month_format_wide => [
-    "M01",
-    "M02",
-    "M03",
-    "M04",
-    "M05",
-    "M06",
-    "M07",
-    "M08",
-    "M09",
-    "M10",
-    "M11",
-    "M12",
+    "Januaar",
+    "Februaar",
+    "M\N{U+00e4}rz",
+    "April",
+    "Mai",
+    "Juni",
+    "Juli",
+    "August",
+    "September",
+    "Oktover",
+    "November",
+    "Dezember",
   ],
   month_stand_alone_abbreviated => [
-    "M01",
-    "M02",
-    "M03",
-    "M04",
-    "M05",
-    "M06",
-    "M07",
-    "M08",
-    "M09",
-    "M10",
-    "M11",
-    "M12",
+    "Januaar",
+    "Februaar",
+    "M\N{U+00e4}rz",
+    "April",
+    "Mai",
+    "Juni",
+    "Juli",
+    "August",
+    "September",
+    "Oktover",
+    "November",
+    "Dezember",
   ],
   month_stand_alone_narrow => [
     1,
@@ -205,24 +205,24 @@
     12,
   ],
   month_stand_alone_wide => [
-    "M01",
-    "M02",
-    "M03",
-    "M04",
-    "M05",
-    "M06",
-    "M07",
-    "M08",
-    "M09",
-    "M10",
-    "M11",
-    "M12",
+    "Januaar",
+    "Februaar",
+    "M\N{U+00e4}rz",
+    "April",
+    "Mai",
+    "Juni",
+    "Juli",
+    "August",
+    "September",
+    "Oktover",
+    "November",
+    "Dezember",
   ],
   name => "Low German Netherlands",
-  native_language => "nds",
-  native_name => "nds NL",
+  native_language => "Neddersass\N{U+2019}sch",
+  native_name => "Neddersass\N{U+2019}sch Nedderlannen",
   native_script => undef,
-  native_territory => "NL",
+  native_territory => "Nedderlannen",
   native_variant => undef,
   quarter_format_abbreviated => [
     "Q1",
@@ -267,5 +267,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 42,
+  version => 47,
 }
