@@ -13,12 +13,13 @@
     EHm => "E HH:mm",
     EHms => "E HH:mm:ss",
     Ed => "E d",
-    Ehm => "E h:mm a",
-    Ehms => "E h:mm:ss a",
+    Ehm => "E h:mm\N{U+202f}a",
+    Ehms => "E h:mm:ss\N{U+202f}a",
     Gy => "y G",
     GyMMM => "MMM y G",
     GyMMMEd => "E, d MMM y G",
     GyMMMd => "d MMM y G",
+    GyMd => "dd.MM.y G",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -29,19 +30,19 @@
     MMM => "LLL",
     MMMEd => "E, d MMM",
     MMMMEd => "E, d MMMM",
-    "MMMMW-count-few" => "'s\N{U+0103}pt\N{U+0103}m\N{U+00e2}na' W 'din' MMM",
-    "MMMMW-count-one" => "'s\N{U+0103}pt\N{U+0103}m\N{U+00e2}na' W 'din' MMM",
-    "MMMMW-count-other" => "'s\N{U+0103}pt\N{U+0103}m\N{U+00e2}na' W 'din' MMM",
+    "MMMMW-count-few" => "'s\N{U+0103}pt\N{U+0103}m\N{U+00e2}na' W 'din' MMMM",
+    "MMMMW-count-one" => "'s\N{U+0103}pt\N{U+0103}m\N{U+00e2}na' W 'din' MMMM",
+    "MMMMW-count-other" => "'s\N{U+0103}pt\N{U+0103}m\N{U+00e2}na' W 'din' MMMM",
     MMMMd => "d MMMM",
     MMMd => "d MMM",
     MMdd => "dd.MM",
     Md => "dd.MM",
     d => "d",
-    h => "h a",
-    hm => "h:mm a",
-    hms => "h:mm:ss a",
-    hmsv => "h:mm:ss a v",
-    hmv => "h:mm a v",
+    h => "h\N{U+202f}a",
+    hm => "h:mm\N{U+202f}a",
+    hms => "h:mm:ss\N{U+202f}a",
+    hmsv => "h:mm:ss\N{U+202f}a v",
+    hmv => "h:mm\N{U+202f}a v",
     ms => "mm:ss",
     y => "y",
     yM => "MM.y",
@@ -273,5 +274,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 34,
+  version => 47,
 }
