@@ -1,70 +1,71 @@
 {
   am_pm_abbreviated => [
-    "\N{U+043f}\N{U+0440}\N{U+0438}\N{U+0458}\N{U+0435} \N{U+043f}\N{U+043e}\N{U+0434}\N{U+043d}\N{U+0435}",
-    "\N{U+043f}\N{U+043e} \N{U+043f}\N{U+043e}\N{U+0434}\N{U+043d}\N{U+0435}",
+    "\N{U+043f}\N{U+0440}\N{U+0438}\N{U+0458}\N{U+0435}\N{U+202f}\N{U+043f}\N{U+043e}\N{U+0434}\N{U+043d}\N{U+0435}",
+    "\N{U+043f}\N{U+043e}\N{U+202f}\N{U+043f}\N{U+043e}\N{U+0434}\N{U+043d}\N{U+0435}",
   ],
   available_formats => {
     Bh => "h B",
     Bhm => "hh:mm B",
     Bhms => "hh:mm:ss B",
     E => "E",
-    EBhm => "E hh:mm B",
-    EBhms => "E hh:mm:ss B",
+    EBhm => "E h:mm B",
+    EBhms => "E, hh:mm:ss B",
     EHm => "E HH:mm",
     EHms => "E HH:mm:ss",
     Ed => "E d.",
-    Ehm => "E h:mm a",
-    Ehms => "E h:mm:ss a",
+    Ehm => "E h:mm\N{U+202f}a",
+    Ehms => "E h:mm:ss\N{U+202f}a",
     Gy => "y. G",
     GyMMM => "MMM y. G",
     GyMMMEd => "E, d. MMM y. G",
     GyMMMd => "d. MMM y. G",
+    GyMd => "d.MM.y. GGGGG",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
     Hmsv => "HH:mm:ss v",
     Hmv => "HH:mm v",
     M => "L",
-    MEd => "E, d.M.",
+    MEd => "E, d. M.",
     MMM => "LLL",
     MMMEd => "E d. MMM",
     MMMMEd => "E, d. MMMM",
-    "MMMMW-count-few" => "W. '\N{U+0441}\N{U+0458}\N{U+0435}\N{U+0434}\N{U+043c}\N{U+0438}\N{U+0446}\N{U+0430}' '\N{U+0443}' MMMM",
-    "MMMMW-count-one" => "W. '\N{U+0441}\N{U+0458}\N{U+0435}\N{U+0434}\N{U+043c}\N{U+0438}\N{U+0446}\N{U+0430}' '\N{U+0443}' MMMM",
+    "MMMMW-count-few" => "MMMM: W. '\N{U+043d}\N{U+0435}\N{U+0434}\N{U+0435}\N{U+0459}\N{U+0430}'",
+    "MMMMW-count-one" => "MMMM: W. '\N{U+043d}\N{U+0435}\N{U+0434}\N{U+0435}\N{U+0459}\N{U+0430}'",
     "MMMMW-count-other" => "W. '\N{U+0441}\N{U+0458}\N{U+0435}\N{U+0434}\N{U+043c}\N{U+0438}\N{U+0446}\N{U+0430}' '\N{U+0443}' MMMM",
     MMMMd => "d. MMMM",
     MMMd => "d. MMM",
     MMMdd => "dd.MMM",
     MMdd => "dd.MM.",
-    Md => "d.M.",
+    Md => "d. M.",
     d => "d",
-    h => "h a",
-    hm => "h:mm a",
-    hms => "h:mm:ss a",
-    hmsv => "h:mm:ss a v",
-    hmv => "h:mm a v",
+    h => "h\N{U+202f}a",
+    hm => "h:mm\N{U+202f}a",
+    hms => "h:mm:ss\N{U+202f}a",
+    hmsv => "h:mm:ss\N{U+202f}a v",
+    hmv => "h:mm\N{U+202f}a v",
     ms => "mm:ss",
     y => "y.",
-    yM => "M.y.",
-    yMEd => "E, d.M.y.",
+    yM => "M. y.",
+    yMEd => "E, d. M. y.",
     yMM => "MM.y.",
     yMMM => "MMM y.",
     yMMMEd => "E, d. MMM y.",
     yMMMM => "MMMM y.",
     yMMMd => "d. MMM y.",
     yMMdd => "dd.MM.y.",
-    yMd => "d.M.y.",
+    yMd => "d. M. y.",
     yQQQ => "QQQ y.",
     yQQQQ => "QQQQ y.",
-    "yw-count-few" => "w. '\N{U+0441}\N{U+0458}\N{U+0435}\N{U+0434}\N{U+043c}\N{U+0438}\N{U+0446}\N{U+0430}' '\N{U+0443}' Y.",
-    "yw-count-one" => "w. '\N{U+0441}\N{U+0458}\N{U+0435}\N{U+0434}\N{U+043c}\N{U+0438}\N{U+0446}\N{U+0430}' '\N{U+0443}' Y.",
+    "yw-count-few" => "w. '\N{U+043d}\N{U+0435}\N{U+0434}\N{U+0435}\N{U+0459}\N{U+0430}' '\N{U+0443}' Y.",
+    "yw-count-one" => "w. '\N{U+043d}\N{U+0435}\N{U+0434}\N{U+0435}\N{U+0459}\N{U+0430}' '\N{U+0443}' Y.",
     "yw-count-other" => "w. '\N{U+0441}\N{U+0458}\N{U+0435}\N{U+0434}\N{U+043c}\N{U+0438}\N{U+0446}\N{U+0430}' '\N{U+0443}' Y.",
   },
   code => "sr-Cyrl-ME",
-  date_format_full => "EEEE, dd. MMMM y.",
-  date_format_long => "dd. MMMM y.",
-  date_format_medium => "dd.MM.y.",
-  date_format_short => "d.M.yy.",
+  date_format_full => "EEEE, d. MMMM y.",
+  date_format_long => "d. MMMM y.",
+  date_format_medium => "d. M. y.",
+  date_format_short => "d. M. y.",
   datetime_format_full => "{1} {0}",
   datetime_format_long => "{1} {0}",
   datetime_format_medium => "{1} {0}",
@@ -233,10 +234,10 @@
   native_territory => "\N{U+0426}\N{U+0440}\N{U+043d}\N{U+0430} \N{U+0413}\N{U+043e}\N{U+0440}\N{U+0430}",
   native_variant => undef,
   quarter_format_abbreviated => [
-    "\N{U+041a}1",
-    "\N{U+041a}2",
-    "\N{U+041a}3",
-    "\N{U+041a}4",
+    "1. \N{U+043a}\N{U+0432}.",
+    "2. \N{U+043a}\N{U+0432}.",
+    "3. \N{U+043a}\N{U+0432}.",
+    "4. \N{U+043a}\N{U+0432}.",
   ],
   quarter_format_narrow => [
     "1.",
@@ -251,10 +252,10 @@
     "\N{U+0447}\N{U+0435}\N{U+0442}\N{U+0432}\N{U+0440}\N{U+0442}\N{U+0438} \N{U+043a}\N{U+0432}\N{U+0430}\N{U+0440}\N{U+0442}\N{U+0430}\N{U+043b}",
   ],
   quarter_stand_alone_abbreviated => [
-    "\N{U+041a}1",
-    "\N{U+041a}2",
-    "\N{U+041a}3",
-    "\N{U+041a}4",
+    "1. \N{U+043a}\N{U+0432}.",
+    "2. \N{U+043a}\N{U+0432}.",
+    "3. \N{U+043a}\N{U+0432}.",
+    "4. \N{U+043a}\N{U+0432}.",
   ],
   quarter_stand_alone_narrow => [
     "1.",
@@ -275,5 +276,5 @@
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 38,
+  version => 47,
 }
