@@ -19,7 +19,7 @@
     GyMMM => "G MMM y",
     GyMMMEd => "G d MMM y E",
     GyMMMd => "G d MMM y",
-    GyMd => "d/M/y GGGGG",
+    GyMd => "GGGGG dd.MM.y",
     H => "HH",
     Hm => "HH:mm",
     Hms => "HH:mm:ss",
@@ -28,7 +28,7 @@
     M => "L",
     MEd => "d/MM E",
     MMM => "LLL",
-    MMMEd => "d MMMM E",
+    MMMEd => "d MMM E",
     MMMMEd => "d MMMM E",
     "MMMMW-count-one" => "MMMM 'ay\N{U+0131}n\N{U+0131}n' W. 'haftas\N{U+0131}'",
     "MMMMW-count-other" => "MMMM 'ay\N{U+0131}n\N{U+0131}n' W. 'haftas\N{U+0131}'",
@@ -223,7 +223,7 @@
     "Kas\N{U+0131}m",
     "Aral\N{U+0131}k",
   ],
-  name => "Turkish Turkey",
+  name => "Turkish T\N{U+00fc}rkiye",
   native_language => "T\N{U+00fc}rk\N{U+00e7}e",
   native_name => "T\N{U+00fc}rk\N{U+00e7}e T\N{U+00fc}rkiye",
   native_script => undef,
@@ -266,11 +266,11 @@
     "4. \N{U+00e7}eyrek",
   ],
   script => undef,
-  territory => "Turkey",
+  territory => "T\N{U+00fc}rkiye",
   time_format_full => "HH:mm:ss zzzz",
   time_format_long => "HH:mm:ss z",
   time_format_medium => "HH:mm:ss",
   time_format_short => "HH:mm",
   variant => undef,
-  version => 42,
+  version => 47,
 }
