@@ -23,6 +23,7 @@ use Scalar::Util qw( reftype );
 use Specio::Declare;
 use Specio::Library::Builtins;
 use Specio::Library::Path::Tiny;
+use Specio::Library::Perl 0.42;
 use Specio::Subs qw( Specio::Library::Builtins );
 use Text::Template;
 
@@ -101,6 +102,13 @@ has _locales => (
     builder => '_build_locales',
 );
 
+has _version => (
+    is      => 'ro',
+    isa     => t('LaxVersionStr'),
+    lazy    => 1,
+    builder => '_build_version',
+);
+
 sub run ($self) {
     binmode STDOUT, ':encoding(UTF-8)'
         or confess $!;
@@ -121,6 +129,14 @@ sub _clean_old_data ($self) {
         say 'Removing ', $path->basename;
         $path->remove;
     }
+
+    $ptr  = Path::Tiny::Rule->new;
+    $iter = $ptr->file->name(qr/\.pl$/)->iter('share');
+    while ( my $path = $iter->() ) {
+        ## no critic (InputOutput::RequireCheckedSyscalls)
+        say 'Removing ', $path->basename;
+        $path->remove;
+    }
 }
 
 sub _build_locales ($self) {
@@ -130,6 +146,7 @@ sub _build_locales ($self) {
             code       => $code,
             cldr_root  => $self->_cldr_root,
             glibc_root => $self->_glibc_root,
+            version    => $self->_version,
         );
 
         ## no critic (InputOutput::RequireCheckedSyscalls)
@@ -144,6 +161,15 @@ sub _build_locales ($self) {
     return \@locales;
 }
 
+sub _build_version ($self) {
+    my $file
+        = path(
+        qw( source-data cldr-json cldr-json cldr-core supplemental languageData.json )
+        );
+    my $data = decode_json( $file->slurp_raw );
+    return $data->{supplemental}{version}{_cldrVersion};
+}
+
 sub _write_data_files ($self) {
     my %raw_locales = $self->_write_data_pm;
 
@@ -188,6 +214,8 @@ sub _write_data_pm ($self) {
         $self->_locales->[0]->version, 1, \$data_pm
     );
 
+    $self->_insert_all_codes( \$data_pm );
+
     $self->_insert_var_in_code( 'Codes',       \%codes,        1, \$data_pm );
     $self->_insert_var_in_code( 'Names',       \%names,        1, \$data_pm );
     $self->_insert_var_in_code( 'NativeNames', \%native_names, 1, \$data_pm );
@@ -209,6 +237,56 @@ sub _write_data_pm ($self) {
     return %raw_locales;
 }
 
+sub _insert_all_codes ( $self, $data_pm ) {
+
+    # AFACIT, the only way to get all the codes is to get them from a names
+    # file like this. I think "en" is pretty much guaranteed to always have a
+    # full list of the codes.
+    my $en_languages = decode_json(
+        $self->_cldr_root->child(
+            qw( cldr-localenames-full main en languages.json  ))->slurp_raw
+    );
+    $self->_insert_var_in_code(
+        'LanguageCodes',
+        $en_languages->{main}{en}{localeDisplayNames}{languages},
+        1,
+        $data_pm,
+    );
+
+    my $en_territories = decode_json(
+        $self->_cldr_root->child(
+            qw( cldr-localenames-full main en territories.json  ))->slurp_raw
+    );
+    $self->_insert_var_in_code(
+        'TerritoryCodes',
+        $en_territories->{main}{en}{localeDisplayNames}{territories},
+        1,
+        $data_pm,
+    );
+
+    my $en_scripts = decode_json(
+        $self->_cldr_root->child(
+            qw( cldr-localenames-full main en scripts.json  ))->slurp_raw
+    );
+    $self->_insert_var_in_code(
+        'ScriptCodes',
+        $en_scripts->{main}{en}{localeDisplayNames}{scripts},
+        1,
+        $data_pm,
+    );
+
+    my $en_variants = decode_json(
+        $self->_cldr_root->child(
+            qw( cldr-localenames-full main en variants.json  ))->slurp_raw
+    );
+    $self->_insert_var_in_code(
+        'VariantCodes',
+        $en_variants->{main}{en}{localeDisplayNames}{variants},
+        1,
+        $data_pm,
+    );
+}
+
 sub _iso_639_aliases ($self) {
     my %aliases;
     for my $locale ( $self->_locales->@* ) {
@@ -378,11 +456,11 @@ sub _write_pod_files ($self) {
         ),
         DateTime->new(
             year      => -10,
-            month     => 9,
-            day       => 15,
-            hour      => 4,
-            minute    => 44,
-            second    => 23,
+            month     =>  9,
+            day       =>  15,
+            hour      =>  4,
+            minute    =>  44,
+            second    =>  23,
             time_zone => 'UTC',
         ),
     );
@@ -426,6 +504,9 @@ sub _build_source_data_root ($self) {
     return $self->_generator_script->parent->parent->child(qw( source-data ));
 }
 
+# apc has no English name.
+my %IncompleteLocales = map { $_ => 1 } qw( apc );
+
 sub _build_locale_codes ($self) {
 
     # We need to have en-US available so we can build a DateTime.pm object.
@@ -443,7 +524,7 @@ sub _build_locale_codes ($self) {
             ->slurp_raw );
 
     return [
-        $avail->{availableLocales}{full}->@*,
+        grep { !$IncompleteLocales{$_} } $avail->{availableLocales}{full}->@*,
         $default->{defaultContent}->@*
     ];
 }
